/* -------------------------------------------------------------------------
 | Copyright (C) 2006  Ali Rawashdeh
 | This program is free software; you can redistribute it and/or modify
 | it under the terms of the GNU General Public License as published by
 | the Free Software Foundation; either version 2 of the License, or
 | (at your option) any later version.
 | 
 | This program is distributed in the hope that it will be useful,
 | but WITHOUT ANY WARRANTY; without even the implied warranty of
 | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 | GNU General Public License for more details.
 | 
 | You should have received a copy of the GNU General Public License along
 | with this program (see License.txt); if not, write to the Free Software
 | Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 --------------------------------------------------------------------------*/
using System;
using System.Text;
using System.Xml;
using System.Xml.Serialization;

namespace HomeDev.RSSTicker.Objects
{
	/// <summary>
	/// This class holds the details for an RSS Feed Bookmark
	/// </summary>
	public class Bookmark
	{
		// Declarations
		private string url_i;
		private int noOfHeadlines_i;
		private string name_i;
		private bool display_i;
		private const int CONST_DEFAULT_NO_OF_HEADLINES = 10;

		#region ctor

		/// <summary>
		/// Instantiates the bookmark class using default values
		/// </summary>
		public Bookmark()
		{
			this.url_i = "Empty";
			this.name_i = "Empty";
			this.noOfHeadlines_i = CONST_DEFAULT_NO_OF_HEADLINES;
			this.Display = true;
		}
		
		/// <summary>
		/// Instantiates an rss feed bookmark and specify the number of headlines
		/// </summary>
		/// <param name="name_p"></param>
		/// <param name="url_p"></param>
		/// <param name="noOfHeadlines_p"></param>
		public Bookmark(string name_p, string url_p, int noOfHeadlines_p)
		{
			this.url_i = url_p;
			this.name_i = name_p;
			this.noOfHeadlines_i = noOfHeadlines_p;
			this.Display = true;
		}

		/// <summary>
		/// Instantiates an rss feed bookmark but uses the default number of headlines
		/// </summary>
		/// <param name="name_p"></param>
		/// <param name="url_p"></param>
		public Bookmark(string name_p, string url_p)
		{
			this.url_i = url_p;
			this.name_i = name_p;
			this.noOfHeadlines_i = CONST_DEFAULT_NO_OF_HEADLINES;
		}

		#endregion ctor

		#region Properties

		/// <summary>
		/// This property holds the name of the RSS Feed Bookmark
		/// </summary>
		[XmlElement("Name")]
		public string Name
		{
			get
			{
				return this.name_i;
			}
			set
			{
				this.name_i = value;
			}
		}

		/// <summary>
		/// This property holds the URL of the RSS Feed
		/// </summary>
		[XmlElement("Url")]
		public string Url
		{
			get
			{
				return this.url_i;
			}
			set
			{
				this.url_i = value;
			}
		}

		/// <summary>
		/// This property holds the number of headlines to be used
		/// </summary>
		[XmlElement("NoOfHeadlines")]
		public int NoOfHeadlines
		{
			get
			{
				return this.noOfHeadlines_i;
			}
			set
			{
				this.noOfHeadlines_i = value;
			}
		}


		/// <summary>
		/// This property holds whether or not the bookmark should be displayed
		/// </summary>
		[XmlElement("Display")]
		public bool Display
		{
			get
			{
				return this.display_i;
			}
			set
			{
				this.display_i = value;
			}
		}

		#endregion Properties

		#region Public Methods

		/// <summary>
		/// This method returns a duplicate of this bookmark object
		/// </summary>
		/// <returns></returns>
		public Bookmark Duplicate()
		{
			Bookmark returnBookmark = new Bookmark();
			returnBookmark.display_i = this.display_i;
			returnBookmark.name_i = this.name_i;
			returnBookmark.NoOfHeadlines = this.noOfHeadlines_i;
			returnBookmark.Url = this.url_i;
			return returnBookmark;
		}

		/// <summary>
		/// This method returns the contents of the Bookmark object
		/// </summary>
		/// <returns></returns>
		public override string ToString()
		{
			StringBuilder sb = new StringBuilder();
			sb.Append("Bookmark: ");
			sb.Append(this.name_i);
			sb.Append(", " + this.url_i);
			sb.Append(", " + this.noOfHeadlines_i);
			
			return sb.ToString();
		}	

		#endregion Public Methods

	}
}
