/* -------------------------------------------------------------------------
 | Copyright (C) 2006  Ali Rawashdeh
 | This program is free software; you can redistribute it and/or modify
 | it under the terms of the GNU General Public License as published by
 | the Free Software Foundation; either version 2 of the License, or
 | (at your option) any later version.
 | 
 | This program is distributed in the hope that it will be useful,
 | but WITHOUT ANY WARRANTY; without even the implied warranty of
 | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 | GNU General Public License for more details.
 | 
 | You should have received a copy of the GNU General Public License along
 | with this program (see License.txt); if not, write to the Free Software
 | Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 --------------------------------------------------------------------------*/
using System;
using System.Collections;
using System.Xml.Serialization;
using System.Xml;
using System.IO;
using System.Text;
using HomeDev.Useful;

namespace HomeDev.RSSTicker.Objects
{
	/// <summary>
	/// Summary description for Bookmarks.
	/// </summary>
	[XmlRoot("Bookmarks")]
	public class Bookmarks
	{
		// Declarations
		ArrayList listBookmarks_i;

		#region ctor

		public Bookmarks()
		{
			listBookmarks_i = new ArrayList();
		}

		#endregion ctor

		#region Properties

		/// <summary>
		/// This method gets and sets the array of bookmark items
		/// </summary>
		[XmlElement("Bookmark")]
		public Bookmark[] Items
		{
			get 
			{
				Bookmark[] bookmarks = new Bookmark[ listBookmarks_i.Count ];
				listBookmarks_i.CopyTo(bookmarks);
				return bookmarks;
			}
			set 
			{
				if(value == null)
				{
					return;
				}
				Bookmark[] bookmarks = (Bookmark[])value;
				listBookmarks_i.Clear();
				foreach( Bookmark bookmark in bookmarks)	
				{
						listBookmarks_i.Add(bookmark);
				}
			}
		}

		#endregion Properties

		#region Public Methods

		// Adds a bookmark to the arraylist of bookmarks
		public void AddBookmark( Bookmark bookmark ) 
		{
			listBookmarks_i.Add( bookmark );
		}

		/// <summary>
		/// This method loads and returns a bookmarks object from the given path
		/// </summary>
		/// <param name="filename_p"></param>
		/// <returns></returns>
		public static Bookmarks Load(string filename_p)
		{
			Bookmarks newBookmarksObject;
			try
			{
				XmlSerializer s = new XmlSerializer( typeof( Bookmarks ) );
				TextReader r = new StreamReader(filename_p);
				newBookmarksObject = (Bookmarks)s.Deserialize(r);
				r.Close();	
			}
			catch(Exception e)
			{
				Logger.Log("Error loading bookmarks file... " + e.Message);
				throw;
			}
			return newBookmarksObject;
		}

		/// <summary>
		/// This method loads and returns a bookmarks object from the given path
		/// </summary>
		/// <param name="filename_p"></param>
		/// <returns></returns>
		public bool Save(string filename_p)
		{
			try
			{
				XmlSerializer s = new XmlSerializer( typeof( Bookmarks ) );
				TextWriter w = new StreamWriter(filename_p);
				s.Serialize( w, this );
				w.Close();
			}
			catch 
			{
				return false;
			}
			return true;
		}


		/// <summary>
		/// This method moves the bookmark object up the list of bookmarks
		/// </summary>
		/// <param name="bookmark_p"></param>
		public void MoveUp(Bookmark bookmark_p)
		{
			int index = this.listBookmarks_i.IndexOf(bookmark_p);
			if(index > 0)
			{
				this.listBookmarks_i.Remove(bookmark_p);
				this.listBookmarks_i.Insert(index - 1, bookmark_p);
			}
		}

		/// <summary>
		/// This method moves the bookmark object down the list of bookmarks
		/// </summary>
		/// <param name="bookmark_p"></param>
		public void MoveDown(Bookmark bookmark_p)
		{
			int index = this.listBookmarks_i.IndexOf(bookmark_p);
			if(index < this.listBookmarks_i.Count - 1)
			{
				this.listBookmarks_i.Remove(bookmark_p);
				this.listBookmarks_i.Insert(index + 1, bookmark_p);
			}
		}

		/// <summary>
		/// This method returns the contents of the object
		/// </summary>
		/// <returns></returns>
		public override string ToString()
		{
			StringBuilder sb = new StringBuilder();
			sb.Append("Bookmarks: \n");
			foreach(Bookmark bookmark in this.listBookmarks_i)
			{
				sb.Append(bookmark.ToString() + "\n");
			}
			
			return sb.ToString();

		}

		#endregion Public Methods
	}
}
