/* -------------------------------------------------------------------------
 | Copyright (C) 2006  Ali Rawashdeh
 | This program is free software; you can redistribute it and/or modify
 | it under the terms of the GNU General Public License as published by
 | the Free Software Foundation; either version 2 of the License, or
 | (at your option) any later version.
 | 
 | This program is distributed in the hope that it will be useful,
 | but WITHOUT ANY WARRANTY; without even the implied warranty of
 | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 | GNU General Public License for more details.
 | 
 | You should have received a copy of the GNU General Public License along
 | with this program (see License.txt); if not, write to the Free Software
 | Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 --------------------------------------------------------------------------*/
using System;
using System.Text;
using HomeDev.Useful;

namespace HomeDev.RSSTicker.Objects
{
	/// <summary>
	/// This object holds the details for a headline
	/// </summary>
	public class Headline
	{
		// Declarations
		private string title_i;
		private string link_i;
		private string description_i;
		private string pubDate_i;

		private bool isNew_i;

		#region ctor

		/// <summary>
		/// Instantiates a Headline object and fills using the data passed in
		/// </summary>
		/// <param name="title_p"></param>
		/// <param name="link_p"></param>
		/// <param name="description_p"></param>
		/// <param name="pubDate_p"></param>
		public Headline(string title_p, string link_p, string description_p, string pubDate_p)
		{
			this.title_i = title_p;
			this.link_i = link_p;
			this.description_i = description_p;
			this.pubDate_i = pubDate_p;
			this.isNew_i = false;
		}

		#endregion ctor

		#region Properties

		/// <summary>
		/// This holds the headline title
		/// </summary>
		public string Title
		{
			get
			{
				return this.title_i;
			}
		}

		/// <summary>
		/// This holds the headline link
		/// </summary>
		public string Link
		{
			get
			{
				return this.link_i;
			}
		}

		/// <summary>
		/// This holds the headline description
		/// </summary>
		public string Description
		{
			get
			{
				return this.description_i;
			}
		}

		/// <summary>
		/// This holds the headline's publication date
		/// </summary>
		public string PubDate
		{
			get
			{
				return this.pubDate_i;
			}
		}

		/// <summary>
		/// Holds whether or not the headline was received on the last update
		/// </summary>
		public bool IsNew
		{
			get
			{
				return this.isNew_i;
			}
			set
			{
				this.isNew_i = value;
			}			
		}

		#endregion Properties

		#region Public Methods

		/// <summary>
		/// This method compares the headline object agains the headline object passed in. At the
		/// moment it only compares using urls, not titles, descriptions or publication dates
		/// </summary>
		/// <param name="otherHeadline_p"></param>
		/// <returns></returns>
		public bool Compare(Headline otherHeadline_p)
		{
			if(this.link_i == otherHeadline_p.Link)
			{
				return true;
			}
			else
			{
				return false;
			}
		}	

		/// <summary>
		/// This method returns the contents of the headline object
		/// </summary>
		/// <returns></returns>
		public override string ToString()
		{
			StringBuilder sb = new StringBuilder();
			sb.Append("Headline: ");
			sb.Append(this.title_i);
			sb.Append(", " + this.link_i);
			sb.Append(", " + this.description_i);
			sb.Append(", " + this.pubDate_i);
			sb.Append(", " + Convert.ToString(this.isNew_i));
			
			return sb.ToString();
		}	

		#endregion Public Methods

	}
}
