/* -------------------------------------------------------------------------
 | Copyright (C) 2006  Ali Rawashdeh
 | This program is free software; you can redistribute it and/or modify
 | it under the terms of the GNU General Public License as published by
 | the Free Software Foundation; either version 2 of the License, or
 | (at your option) any later version.
 | 
 | This program is distributed in the hope that it will be useful,
 | but WITHOUT ANY WARRANTY; without even the implied warranty of
 | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 | GNU General Public License for more details.
 | 
 | You should have received a copy of the GNU General Public License along
 | with this program (see License.txt); if not, write to the Free Software
 | Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 --------------------------------------------------------------------------*/
using System;
using System.Windows.Forms;
using System.Diagnostics;
using Microsoft.Win32;

namespace HomeDev.RSSTicker.Objects
{
	/// <summary>
	/// This class holds the static event handler method for the linklabel click event
	/// </summary>
	public class LabelLinkClick
	{

		private static string browserPath;
		public static bool newBrowser;

		/// <summary>
		/// This method is called when a linklabel is clicked
		/// </summary>
		/// <param name="sender"></param>
		/// <param name="e"></param>
		public static void LinkLabelClick(object sender, System.Windows.Forms.LinkLabelLinkClickedEventArgs e)
		{
			if(newBrowser)
			{
				Process p = new Process();
				if((browserPath == null) || (browserPath == String.Empty))
				{
					browserPath = getDefaultBrowserPath();
				}
				p.StartInfo.FileName = browserPath;
				p.StartInfo.Arguments = (string)e.Link.LinkData;
				p.Start();
			}
			else
			{
				System.Diagnostics.Process.Start((string)e.Link.LinkData);
			}
		}

		/// <summary>
		/// This method gets the path of the default browser from the registry
		/// </summary>
		/// <returns></returns>
		private static string getDefaultBrowserPath()
		{
			// Declare
			string path;
			RegistryKey defaultKey;
			
			// Get the default browser registry key
			defaultKey = Registry.ClassesRoot.OpenSubKey(@"HTTP\shell\open\command", false);

			// Trim the text
			path = defaultKey.GetValue(null).ToString().ToLower().Replace("\"", "");
			path = path.Substring(0, path.LastIndexOf(".exe")+4);

			//Dispose
			if(defaultKey != null)
			{
				defaultKey.Close();
			}
			
			return path;
		}
	}
}
