/* -------------------------------------------------------------------------
 | Copyright (C) 2006  Ali Rawashdeh
 | This program is free software; you can redistribute it and/or modify
 | it under the terms of the GNU General Public License as published by
 | the Free Software Foundation; either version 2 of the License, or
 | (at your option) any later version.
 | 
 | This program is distributed in the hope that it will be useful,
 | but WITHOUT ANY WARRANTY; without even the implied warranty of
 | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 | GNU General Public License for more details.
 | 
 | You should have received a copy of the GNU General Public License along
 | with this program (see License.txt); if not, write to the Free Software
 | Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 --------------------------------------------------------------------------*/
using System;
using System.Xml;
using System.Xml.Serialization;
using System.IO;
using System.Text;	
using HomeDev.Useful;

namespace HomeDev.RSSTicker.Objects
{
	/// <summary>
	/// Summary description for Settings.
	/// </summary>
	[XmlRoot("Settings")]
	public class Settings
	{
	
		// Declarations
		private int speed_i;
		private int updatePeriod_i;
		private bool newBrowser_i;

		#region ctor

		public Settings()
		{
			// Set the speed to a default value
			speed_i = 50;

			// Set the update period to a default value
			updatePeriod_i = 2;

			// Set the new browser property to default to true
			newBrowser_i = true;
		}

		#endregion ctor

		#region Properties

		/// <summary>
		/// This item holds the speed at which the RSS Ticker scrolls
		/// </summary>
		[XmlElement("Speed")]
		public int Speed
		{
			get
			{
				return this.speed_i;
			}
			set
			{
				this.speed_i = value;
			}
		}

		/// <summary>
		/// This item holds the number of minutes between each rss feed update
		/// </summary>
		[XmlElement("UpdatePeriod")]
		public int UpdatePeriod
		{
			get
			{
				return this.updatePeriod_i;
			}
			set
			{
				this.updatePeriod_i = value;
			}
		}

		/// <summary>
		/// This item holds the number of minutes between each rss feed update
		/// </summary>
		[XmlElement("NewBrowser")]
		public bool NewBrowser
		{
			get
			{
				return this.newBrowser_i;
			}
			set
			{
				this.newBrowser_i = value;
			}
		}

		#endregion Properties
		
		#region Public Methods

		/// <summary>
		/// This method loads and returns a settings object from the given path
		/// </summary>
		/// <param name="filename_p"></param>
		/// <returns></returns>
		public static Settings Load(string filename_p)
		{
			Settings newSettingsObject;
			try
			{
				XmlSerializer s = new XmlSerializer( typeof( Settings ) );
				TextReader r = new StreamReader(filename_p);
				newSettingsObject = (Settings)s.Deserialize(r);
				r.Close();	
			}
			catch(Exception e)
			{
				Logger.Log("Error loading settings file... " + e.Message);
				throw;
			}
			return newSettingsObject;
		}

		/// <summary>
		/// This method loads and returns a settings object from the given path
		/// </summary>
		/// <param name="filename_p"></param>
		/// <returns></returns>
		public bool Save(string filename_p)
		{
			try
			{
				XmlSerializer s = new XmlSerializer( typeof( Settings ) );
				TextWriter w = new StreamWriter(filename_p);
				s.Serialize( w, this );
				w.Close();
			}
			catch 
			{
				return false;
			}
			return true;
		}

		/// <summary>
		/// This method returns the contents of the Settings object
		/// </summary>
		/// <returns></returns>
		public override string ToString()
		{
			StringBuilder sb = new StringBuilder();
			sb.Append("Settings: ");
			sb.Append(this.speed_i);
			sb.Append(", " + this.updatePeriod_i);
			return sb.ToString();
		}

		#endregion Public Methods

	}
}
