/* -------------------------------------------------------------------------
 | Copyright (C) 2006  Ali Rawashdeh
 | This program is free software; you can redistribute it and/or modify
 | it under the terms of the GNU General Public License as published by
 | the Free Software Foundation; either version 2 of the License, or
 | (at your option) any later version.
 | 
 | This program is distributed in the hope that it will be useful,
 | but WITHOUT ANY WARRANTY; without even the implied warranty of
 | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 | GNU General Public License for more details.
 | 
 | You should have received a copy of the GNU General Public License along
 | with this program (see License.txt); if not, write to the Free Software
 | Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 --------------------------------------------------------------------------*/
using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using HomeDev.RSSTicker.Objects;
using HomeDev.RSSTicker.Controller;

namespace HomeDev.RSSTicker.UI
{
	/// <summary>
	/// Summary description for BookmarkForm.
	/// </summary>
	public class BookmarkForm : System.Windows.Forms.Form
	{
		// Declarations
		private System.Windows.Forms.TextBox nameTextBox_i;
		private System.Windows.Forms.TextBox linkTextBox_i;
		private System.Windows.Forms.CheckBox displayCheckBox_i;
		private System.Windows.Forms.Label labelName_i;
		private System.Windows.Forms.Label labelLink_i;
		private System.Windows.Forms.Label label1;
		private System.Windows.Forms.Button saveButton_i;
		private System.Windows.Forms.Button cancelButton_i;
		private System.Windows.Forms.TextBox noOfHeadlinesTextBox_i;
		private System.Windows.Forms.GroupBox groupBox1;
		private System.Windows.Forms.PictureBox pbNameValid_i;
		private System.Windows.Forms.PictureBox pbValidatorExplanation_i;
		private System.Windows.Forms.Label lblValidatorExplanation_i;
		private System.Windows.Forms.PictureBox pbLinkValid_i;
		private System.ComponentModel.IContainer components;

		private bool add_i;
		private bool addBookMark;
		private Bookmark bookmark_i;
		private HomeDev.RSSTicker.Controller.Controller controller_i;
		private EnableBookmarksFormDelegate enableBookmarksFormDelegate_i;
		private System.Windows.Forms.Button uwasaButton;
		private System.Windows.Forms.Button jitsurokuButton;
		private System.Windows.Forms.Button IPOButton;
		private System.Windows.Forms.Button foreignButton;
		private System.Windows.Forms.Button summary_kaigaiButton;
		private System.Windows.Forms.Button summary_kokunaiButton;
		private System.Windows.Forms.Button keizaiButton;
		private System.Windows.Forms.Button ratingButton;
		private System.Windows.Forms.Button kabuka_rankingButton;
		private System.Windows.Forms.Button kessan_scheduleButton;
		private System.Windows.Forms.Button kessan_explanatoryButton;
		private System.Windows.Forms.Button gyosekiButton;
		private System.Windows.Forms.Button bunkatsuButton;
		private System.Windows.Forms.Button hotnewsButton;
		private System.Windows.Forms.Button chumokuButton;
		private System.Windows.Forms.Button digestButton;
		private System.Windows.Forms.Label label2;
		private System.Windows.Forms.Label label3;
		private System.Windows.Forms.Button exchangeButton;
		private System.Windows.Forms.Button stockButton;
		private System.Windows.Forms.Button exchangeButton2;
		private System.Windows.Forms.Timer timer1;
		
		#region ctor

		/// <summary>
		/// Constructor for BookmarkForm
		/// </summary>
		/// <param name="controller_p">The current controller object</param>
		/// <param name="bookmark_p">The bookmark to be editted, null if a new one is to be created</param>
		/// <param name="enableBookmarksFormDelegate_p">The delegate to return control to the BookmarksForm</param>
		public BookmarkForm(HomeDev.RSSTicker.Controller.Controller controller_p, Bookmark bookmark_p,
			EnableBookmarksFormDelegate enableBookmarksFormDelegate_p)
		{
			// Required for Windows Form Designer support
			InitializeComponent();
			
			// Assign the controller object
			controller_i = controller_p;
			bookmark_i = bookmark_p;
			enableBookmarksFormDelegate_i = enableBookmarksFormDelegate_p;

			// Set up the Event Handlers
			this.cancelButton_i.Click += new EventHandler(this.cancelButton_MouseDown);
			this.saveButton_i.Click += new EventHandler(this.saveButton_MouseDown);

			if(bookmark_p == null)
			{
				// It is a new bookmark
				add_i = true;
				this.Text += " - New";
			}
			else
			{
				// Editting an existing bookmark
				add_i = false;
				UpdateInfo();
				this.Text += " - " + bookmark_p.Name;
			}
		}

		#endregion ctor
		
		#region Event Handler Methods

		/// <summary>
		/// This method is called when the Cancel button is pressed
		/// </summary>
		public void cancelButton_MouseDown(object source, EventArgs args)
		{
			this.Close();
		}

		/// <summary>
		/// This method is called when the Ok button is pressed
		/// </summary>
		public void saveButton_MouseDown(object source, EventArgs args)
		{
			// Add the new bookmark or save an existing one
			if(add_i)
			{
				// Validate that the required data is entered
				if(!ValidateFields())
				{
					return;
				}

				// Copy the entered data into a new Bookmark object
				this.bookmark_i = new Bookmark();
				this.bookmark_i.Name = this.nameTextBox_i.Text;
				this.bookmark_i.Url = this.linkTextBox_i.Text;
				// 07/11 Y.T ADD & DEBUG
				Console.WriteLine("this.bookmark_i.Name_1:" + this.bookmark_i.Name);
				Console.WriteLine("this.bookmark_i.Url_1:" + this.bookmark_i.Url);
				// 07/11 Y.T END
				if(this.noOfHeadlinesTextBox_i.Text != "")
				{
					this.bookmark_i.NoOfHeadlines = Convert.ToInt32(this.noOfHeadlinesTextBox_i.Text);
				}
				this.bookmark_i.Display = this.displayCheckBox_i.Checked;
				
				// Add the bookmark to the list of bookmarks
				this.controller_i.Bookmarks.AddBookmark(this.bookmark_i);
				this.Close();
			}
			else
			{

				// Validate that the required data is entered
				if(!ValidateFields())
				{
					return;
				}
				// 07/11 Y.T ADD & DEBUG
				Console.WriteLine("this.bookmark_i.Name_2:" + this.bookmark_i.Name);
				Console.WriteLine("this.bookmark_i.Url_2:" + this.bookmark_i.Url);
				// 07/11 Y.T END
				this.bookmark_i.Name = this.nameTextBox_i.Text;
				this.bookmark_i.Url = this.linkTextBox_i.Text;
				if(this.noOfHeadlinesTextBox_i.Text != "")
				{
					this.bookmark_i.NoOfHeadlines = Convert.ToInt32(this.noOfHeadlinesTextBox_i.Text);
				}
				this.bookmark_i.Display = this.displayCheckBox_i.Checked;
				this.Close();
			}
			
		}
		
		/// <summary>
		/// This method is called when the form is closed
		/// </summary>
		/// <param name="sender"></param>
		/// <param name="e"></param>
		private void BookmarkForm_Closing(object sender, System.ComponentModel.CancelEventArgs e)
		{
			enableBookmarksFormDelegate_i();
		}

		#endregion Event Handler Methods

		#region Other Methods

		/// <summary>
		/// This method checks that the required fields have been filled in
		/// </summary>
		/// <returns></returns>
		private bool ValidateFields()
		{
			// Hide the validator eplanation
			this.pbValidatorExplanation_i.Visible = false;
			this.lblValidatorExplanation_i.Visible = false;

			bool valid = true;

			// Check that the Name field is filled in
			if(this.nameTextBox_i.Text == "")
			{
				valid = false;
				this.pbNameValid_i.Visible = true;
			}
			else
			{
				this.pbNameValid_i.Visible = false;
			}
					
			// Check that the Link field is filled in
			if ((this.linkTextBox_i.Text == "") || (this.linkTextBox_i.Text == "http://"))
			{
				valid = false;
				this.pbLinkValid_i.Visible = true;
			}
			else
			{
				this.pbLinkValid_i.Visible = false;
			}

			// If one of the fields doesnt exist then show the validator explanation
			if(!valid)
			{
				this.pbValidatorExplanation_i.Visible = true;
				this.lblValidatorExplanation_i.Visible = true;
			}

			//2006/07/11 Y.T ADD
			if(addBookMark)
			{
				valid = true;
			}
			//2006/07/11 Y.T END

			return valid;
		}

		/// <summary>
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#endregion Other Methods

		#region Public Methods

		/// <summary>
		/// This method updates the info on the screen with the data stored in the bookmark
		/// </summary>
		public void UpdateInfo()
		{
			this.nameTextBox_i.Text = bookmark_i.Name;
			this.linkTextBox_i.Text = bookmark_i.Url;
			this.noOfHeadlinesTextBox_i.Text = Convert.ToString(bookmark_i.NoOfHeadlines);
			this.displayCheckBox_i.Checked = bookmark_i.Display;
		}

		#endregion Public Methods

		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			this.components = new System.ComponentModel.Container();
			System.Resources.ResourceManager resources = new System.Resources.ResourceManager(typeof(BookmarkForm));
			this.nameTextBox_i = new System.Windows.Forms.TextBox();
			this.linkTextBox_i = new System.Windows.Forms.TextBox();
			this.noOfHeadlinesTextBox_i = new System.Windows.Forms.TextBox();
			this.displayCheckBox_i = new System.Windows.Forms.CheckBox();
			this.labelName_i = new System.Windows.Forms.Label();
			this.labelLink_i = new System.Windows.Forms.Label();
			this.label1 = new System.Windows.Forms.Label();
			this.saveButton_i = new System.Windows.Forms.Button();
			this.cancelButton_i = new System.Windows.Forms.Button();
			this.groupBox1 = new System.Windows.Forms.GroupBox();
			this.pbLinkValid_i = new System.Windows.Forms.PictureBox();
			this.pbNameValid_i = new System.Windows.Forms.PictureBox();
			this.pbValidatorExplanation_i = new System.Windows.Forms.PictureBox();
			this.lblValidatorExplanation_i = new System.Windows.Forms.Label();
			this.timer1 = new System.Windows.Forms.Timer(this.components);
			this.uwasaButton = new System.Windows.Forms.Button();
			this.jitsurokuButton = new System.Windows.Forms.Button();
			this.IPOButton = new System.Windows.Forms.Button();
			this.foreignButton = new System.Windows.Forms.Button();
			this.summary_kaigaiButton = new System.Windows.Forms.Button();
			this.summary_kokunaiButton = new System.Windows.Forms.Button();
			this.keizaiButton = new System.Windows.Forms.Button();
			this.ratingButton = new System.Windows.Forms.Button();
			this.kabuka_rankingButton = new System.Windows.Forms.Button();
			this.kessan_scheduleButton = new System.Windows.Forms.Button();
			this.kessan_explanatoryButton = new System.Windows.Forms.Button();
			this.gyosekiButton = new System.Windows.Forms.Button();
			this.bunkatsuButton = new System.Windows.Forms.Button();
			this.hotnewsButton = new System.Windows.Forms.Button();
			this.chumokuButton = new System.Windows.Forms.Button();
			this.digestButton = new System.Windows.Forms.Button();
			this.label2 = new System.Windows.Forms.Label();
			this.label3 = new System.Windows.Forms.Label();
			this.exchangeButton = new System.Windows.Forms.Button();
			this.stockButton = new System.Windows.Forms.Button();
			this.exchangeButton2 = new System.Windows.Forms.Button();
			this.groupBox1.SuspendLayout();
			this.SuspendLayout();
			// 
			// nameTextBox_i
			// 
			this.nameTextBox_i.Location = new System.Drawing.Point(64, 22);
			this.nameTextBox_i.Name = "nameTextBox_i";
			this.nameTextBox_i.Size = new System.Drawing.Size(280, 19);
			this.nameTextBox_i.TabIndex = 0;
			this.nameTextBox_i.Text = "";
			// 
			// linkTextBox_i
			// 
			this.linkTextBox_i.Location = new System.Drawing.Point(64, 60);
			this.linkTextBox_i.Name = "linkTextBox_i";
			this.linkTextBox_i.Size = new System.Drawing.Size(280, 19);
			this.linkTextBox_i.TabIndex = 2;
			this.linkTextBox_i.Text = "http://";
			// 
			// noOfHeadlinesTextBox_i
			// 
			this.noOfHeadlinesTextBox_i.Location = new System.Drawing.Point(160, 99);
			this.noOfHeadlinesTextBox_i.Name = "noOfHeadlinesTextBox_i";
			this.noOfHeadlinesTextBox_i.Size = new System.Drawing.Size(24, 19);
			this.noOfHeadlinesTextBox_i.TabIndex = 3;
			this.noOfHeadlinesTextBox_i.Text = "5";
			this.noOfHeadlinesTextBox_i.TextAlign = System.Windows.Forms.HorizontalAlignment.Center;
			// 
			// displayCheckBox_i
			// 
			this.displayCheckBox_i.CheckAlign = System.Drawing.ContentAlignment.TopRight;
			this.displayCheckBox_i.Checked = true;
			this.displayCheckBox_i.CheckState = System.Windows.Forms.CheckState.Checked;
			this.displayCheckBox_i.Location = new System.Drawing.Point(208, 99);
			this.displayCheckBox_i.Name = "displayCheckBox_i";
			this.displayCheckBox_i.Size = new System.Drawing.Size(92, 18);
			this.displayCheckBox_i.TabIndex = 4;
			this.displayCheckBox_i.Text = "Display Feed:";
			this.displayCheckBox_i.TextAlign = System.Drawing.ContentAlignment.TopLeft;
			// 
			// labelName_i
			// 
			this.labelName_i.Location = new System.Drawing.Point(16, 26);
			this.labelName_i.Name = "labelName_i";
			this.labelName_i.Size = new System.Drawing.Size(40, 21);
			this.labelName_i.TabIndex = 7;
			this.labelName_i.Text = "OF";
			// 
			// labelLink_i
			// 
			this.labelLink_i.Location = new System.Drawing.Point(16, 62);
			this.labelLink_i.Name = "labelLink_i";
			this.labelLink_i.Size = new System.Drawing.Size(40, 22);
			this.labelLink_i.TabIndex = 8;
			this.labelLink_i.Text = "NF";
			// 
			// label1
			// 
			this.label1.Location = new System.Drawing.Point(16, 104);
			this.label1.Name = "label1";
			this.label1.Size = new System.Drawing.Size(152, 18);
			this.label1.TabIndex = 6;
			this.label1.Text = "\ő^CgF";
			// 
			// saveButton_i
			// 
			this.saveButton_i.Location = new System.Drawing.Point(400, 24);
			this.saveButton_i.Name = "saveButton_i";
			this.saveButton_i.Size = new System.Drawing.Size(104, 24);
			this.saveButton_i.TabIndex = 5;
			this.saveButton_i.Text = "ۑ";
			// 
			// cancelButton_i
			// 
			this.cancelButton_i.Location = new System.Drawing.Point(400, 56);
			this.cancelButton_i.Name = "cancelButton_i";
			this.cancelButton_i.Size = new System.Drawing.Size(104, 26);
			this.cancelButton_i.TabIndex = 6;
			this.cancelButton_i.Text = "Cancel";
			// 
			// groupBox1
			// 
			this.groupBox1.Controls.Add(this.pbLinkValid_i);
			this.groupBox1.Controls.Add(this.pbNameValid_i);
			this.groupBox1.Controls.Add(this.noOfHeadlinesTextBox_i);
			this.groupBox1.Controls.Add(this.displayCheckBox_i);
			this.groupBox1.Controls.Add(this.nameTextBox_i);
			this.groupBox1.Controls.Add(this.linkTextBox_i);
			this.groupBox1.Controls.Add(this.labelLink_i);
			this.groupBox1.Controls.Add(this.labelName_i);
			this.groupBox1.Controls.Add(this.label1);
			this.groupBox1.Controls.Add(this.pbValidatorExplanation_i);
			this.groupBox1.Controls.Add(this.lblValidatorExplanation_i);
			this.groupBox1.Controls.Add(this.saveButton_i);
			this.groupBox1.Controls.Add(this.cancelButton_i);
			this.groupBox1.Location = new System.Drawing.Point(8, 7);
			this.groupBox1.Name = "groupBox1";
			this.groupBox1.Size = new System.Drawing.Size(528, 129);
			this.groupBox1.TabIndex = 0;
			this.groupBox1.TabStop = false;
			this.groupBox1.Text = "ubN}[N";
			// 
			// pbLinkValid_i
			// 
			this.pbLinkValid_i.Image = ((System.Drawing.Image)(resources.GetObject("pbLinkValid_i.Image")));
			this.pbLinkValid_i.Location = new System.Drawing.Point(352, 60);
			this.pbLinkValid_i.Name = "pbLinkValid_i";
			this.pbLinkValid_i.Size = new System.Drawing.Size(20, 18);
			this.pbLinkValid_i.TabIndex = 8;
			this.pbLinkValid_i.TabStop = false;
			this.pbLinkValid_i.Visible = false;
			// 
			// pbNameValid_i
			// 
			this.pbNameValid_i.Image = ((System.Drawing.Image)(resources.GetObject("pbNameValid_i.Image")));
			this.pbNameValid_i.Location = new System.Drawing.Point(352, 22);
			this.pbNameValid_i.Name = "pbNameValid_i";
			this.pbNameValid_i.Size = new System.Drawing.Size(20, 19);
			this.pbNameValid_i.TabIndex = 7;
			this.pbNameValid_i.TabStop = false;
			this.pbNameValid_i.Visible = false;
			// 
			// pbValidatorExplanation_i
			// 
			this.pbValidatorExplanation_i.Image = ((System.Drawing.Image)(resources.GetObject("pbValidatorExplanation_i.Image")));
			this.pbValidatorExplanation_i.Location = new System.Drawing.Point(352, 99);
			this.pbValidatorExplanation_i.Name = "pbValidatorExplanation_i";
			this.pbValidatorExplanation_i.Size = new System.Drawing.Size(20, 19);
			this.pbValidatorExplanation_i.TabIndex = 10;
			this.pbValidatorExplanation_i.TabStop = false;
			this.pbValidatorExplanation_i.Visible = false;
			// 
			// lblValidatorExplanation_i
			// 
			this.lblValidatorExplanation_i.Location = new System.Drawing.Point(376, 102);
			this.lblValidatorExplanation_i.Name = "lblValidatorExplanation_i";
			this.lblValidatorExplanation_i.Size = new System.Drawing.Size(96, 15);
			this.lblValidatorExplanation_i.TabIndex = 11;
			this.lblValidatorExplanation_i.Text = "- LĂ";
			this.lblValidatorExplanation_i.Visible = false;
			// 
			// uwasaButton
			// 
			this.uwasaButton.Location = new System.Drawing.Point(144, 168);
			this.uwasaButton.Name = "uwasaButton";
			this.uwasaButton.Size = new System.Drawing.Size(120, 23);
			this.uwasaButton.TabIndex = 7;
			this.uwasaButton.Text = "̉\";
			this.uwasaButton.Click += new System.EventHandler(this.uwasaButton_Click);
			// 
			// jitsurokuButton
			// 
			this.jitsurokuButton.Location = new System.Drawing.Point(280, 168);
			this.jitsurokuButton.Name = "jitsurokuButton";
			this.jitsurokuButton.Size = new System.Drawing.Size(120, 23);
			this.jitsurokuButton.TabIndex = 8;
			this.jitsurokuButton.Text = "^";
			this.jitsurokuButton.Click += new System.EventHandler(this.jitsurokuButton_Click);
			// 
			// IPOButton
			// 
			this.IPOButton.Location = new System.Drawing.Point(416, 168);
			this.IPOButton.Name = "IPOButton";
			this.IPOButton.Size = new System.Drawing.Size(120, 23);
			this.IPOButton.TabIndex = 9;
			this.IPOButton.Text = "IPO";
			this.IPOButton.Click += new System.EventHandler(this.IPOButton_Click);
			// 
			// foreignButton
			// 
			this.foreignButton.Location = new System.Drawing.Point(8, 208);
			this.foreignButton.Name = "foreignButton";
			this.foreignButton.Size = new System.Drawing.Size(120, 23);
			this.foreignButton.TabIndex = 10;
			this.foreignButton.Text = "On";
			this.foreignButton.Click += new System.EventHandler(this.foreignButton_Click);
			// 
			// summary_kaigaiButton
			// 
			this.summary_kaigaiButton.Location = new System.Drawing.Point(144, 208);
			this.summary_kaigaiButton.Name = "summary_kaigaiButton";
			this.summary_kaigaiButton.Size = new System.Drawing.Size(120, 23);
			this.summary_kaigaiButton.TabIndex = 11;
			this.summary_kaigaiButton.Text = "COsT";
			this.summary_kaigaiButton.Click += new System.EventHandler(this.summary_kaigaiButton_Click);
			// 
			// summary_kokunaiButton
			// 
			this.summary_kokunaiButton.Location = new System.Drawing.Point(280, 208);
			this.summary_kokunaiButton.Name = "summary_kokunaiButton";
			this.summary_kokunaiButton.Size = new System.Drawing.Size(120, 23);
			this.summary_kokunaiButton.TabIndex = 12;
			this.summary_kokunaiButton.Text = "sT";
			this.summary_kokunaiButton.Click += new System.EventHandler(this.summary_kokunaiButton_Click);
			// 
			// keizaiButton
			// 
			this.keizaiButton.Location = new System.Drawing.Point(416, 208);
			this.keizaiButton.Name = "keizaiButton";
			this.keizaiButton.Size = new System.Drawing.Size(120, 23);
			this.keizaiButton.TabIndex = 13;
			this.keizaiButton.Text = "oώwWEv";
			this.keizaiButton.Click += new System.EventHandler(this.keizaiButton_Click);
			// 
			// ratingButton
			// 
			this.ratingButton.Location = new System.Drawing.Point(8, 248);
			this.ratingButton.Name = "ratingButton";
			this.ratingButton.Size = new System.Drawing.Size(120, 23);
			this.ratingButton.TabIndex = 14;
			this.ratingButton.Text = "it";
			this.ratingButton.Click += new System.EventHandler(this.ratingButton_Click);
			// 
			// kabuka_rankingButton
			// 
			this.kabuka_rankingButton.Location = new System.Drawing.Point(144, 248);
			this.kabuka_rankingButton.Name = "kabuka_rankingButton";
			this.kabuka_rankingButton.Size = new System.Drawing.Size(120, 23);
			this.kabuka_rankingButton.TabIndex = 15;
			this.kabuka_rankingButton.Text = "LO";
			this.kabuka_rankingButton.Click += new System.EventHandler(this.kabuka_rankingButton_Click);
			// 
			// kessan_scheduleButton
			// 
			this.kessan_scheduleButton.Location = new System.Drawing.Point(280, 248);
			this.kessan_scheduleButton.Name = "kessan_scheduleButton";
			this.kessan_scheduleButton.Size = new System.Drawing.Size(120, 23);
			this.kessan_scheduleButton.TabIndex = 16;
			this.kessan_scheduleButton.Text = "Z\\";
			this.kessan_scheduleButton.Click += new System.EventHandler(this.kessan_scheduleButton_Click);
			// 
			// kessan_explanatoryButton
			// 
			this.kessan_explanatoryButton.Location = new System.Drawing.Point(416, 248);
			this.kessan_explanatoryButton.Name = "kessan_explanatoryButton";
			this.kessan_explanatoryButton.Size = new System.Drawing.Size(120, 23);
			this.kessan_explanatoryButton.TabIndex = 17;
			this.kessan_explanatoryButton.Text = "Z\";
			this.kessan_explanatoryButton.Click += new System.EventHandler(this.kessan_explanatoryButton_Click);
			// 
			// gyosekiButton
			// 
			this.gyosekiButton.Location = new System.Drawing.Point(8, 288);
			this.gyosekiButton.Name = "gyosekiButton";
			this.gyosekiButton.Size = new System.Drawing.Size(120, 23);
			this.gyosekiButton.TabIndex = 18;
			this.gyosekiButton.Text = "ƋƐуj[X";
			this.gyosekiButton.Click += new System.EventHandler(this.gyosekiButton_Click);
			// 
			// bunkatsuButton
			// 
			this.bunkatsuButton.Location = new System.Drawing.Point(144, 288);
			this.bunkatsuButton.Name = "bunkatsuButton";
			this.bunkatsuButton.Size = new System.Drawing.Size(120, 23);
			this.bunkatsuButton.TabIndex = 19;
			this.bunkatsuButton.Text = "EzE";
			this.bunkatsuButton.Click += new System.EventHandler(this.bunkatsuButton_Click);
			// 
			// hotnewsButton
			// 
			this.hotnewsButton.Location = new System.Drawing.Point(280, 288);
			this.hotnewsButton.Name = "hotnewsButton";
			this.hotnewsButton.Size = new System.Drawing.Size(120, 23);
			this.hotnewsButton.TabIndex = 20;
			this.hotnewsButton.Text = "Vzbgj[X";
			this.hotnewsButton.Click += new System.EventHandler(this.hotnewsButton_Click);
			// 
			// chumokuButton
			// 
			this.chumokuButton.Location = new System.Drawing.Point(416, 288);
			this.chumokuButton.Name = "chumokuButton";
			this.chumokuButton.Size = new System.Drawing.Size(120, 23);
			this.chumokuButton.TabIndex = 21;
			this.chumokuButton.Text = "ڊ̓";
			this.chumokuButton.Click += new System.EventHandler(this.chumokuButton_Click);
			// 
			// digestButton
			// 
			this.digestButton.Location = new System.Drawing.Point(8, 168);
			this.digestButton.Name = "digestButton";
			this.digestButton.Size = new System.Drawing.Size(120, 23);
			this.digestButton.TabIndex = 22;
			this.digestButton.Text = "،_CWFXg";
			this.digestButton.Click += new System.EventHandler(this.digestButton_Click);
			// 
			// label2
			// 
			this.label2.Location = new System.Drawing.Point(8, 144);
			this.label2.Name = "label2";
			this.label2.Size = new System.Drawing.Size(144, 16);
			this.label2.TabIndex = 23;
			this.label2.Text = "- 暌VŐVj[X -";
			// 
			// label3
			// 
			this.label3.Location = new System.Drawing.Point(16, 328);
			this.label3.Name = "label3";
			this.label3.Size = new System.Drawing.Size(200, 16);
			this.label3.TabIndex = 24;
			this.label3.Text = "- A^C@ב/o  -";
			// 
			// exchangeButton
			// 
			this.exchangeButton.Location = new System.Drawing.Point(8, 352);
			this.exchangeButton.Name = "exchangeButton";
			this.exchangeButton.Size = new System.Drawing.Size(120, 23);
			this.exchangeButton.TabIndex = 25;
			this.exchangeButton.Text = "Oב(JPY)";
			this.exchangeButton.Click += new System.EventHandler(this.exchangeButton_Click);
			// 
			// stockButton
			// 
			this.stockButton.Location = new System.Drawing.Point(280, 352);
			this.stockButton.Name = "stockButton";
			this.stockButton.Size = new System.Drawing.Size(120, 23);
			this.stockButton.TabIndex = 26;
			this.stockButton.Text = "o";
			this.stockButton.Click += new System.EventHandler(this.stockButton_Click);
			// 
			// exchangeButton2
			// 
			this.exchangeButton2.Location = new System.Drawing.Point(144, 352);
			this.exchangeButton2.Name = "exchangeButton2";
			this.exchangeButton2.Size = new System.Drawing.Size(120, 23);
			this.exchangeButton2.TabIndex = 27;
			this.exchangeButton2.Text = "Oב(USD)";
			this.exchangeButton2.Click += new System.EventHandler(this.exchangeButton2_Click);
			// 
			// BookmarkForm
			// 
			this.AutoScale = false;
			this.AutoScaleBaseSize = new System.Drawing.Size(5, 12);
			this.ClientSize = new System.Drawing.Size(548, 382);
			this.Controls.Add(this.exchangeButton2);
			this.Controls.Add(this.stockButton);
			this.Controls.Add(this.exchangeButton);
			this.Controls.Add(this.label3);
			this.Controls.Add(this.label2);
			this.Controls.Add(this.digestButton);
			this.Controls.Add(this.chumokuButton);
			this.Controls.Add(this.hotnewsButton);
			this.Controls.Add(this.bunkatsuButton);
			this.Controls.Add(this.gyosekiButton);
			this.Controls.Add(this.kessan_explanatoryButton);
			this.Controls.Add(this.kessan_scheduleButton);
			this.Controls.Add(this.kabuka_rankingButton);
			this.Controls.Add(this.ratingButton);
			this.Controls.Add(this.keizaiButton);
			this.Controls.Add(this.summary_kokunaiButton);
			this.Controls.Add(this.summary_kaigaiButton);
			this.Controls.Add(this.foreignButton);
			this.Controls.Add(this.IPOButton);
			this.Controls.Add(this.jitsurokuButton);
			this.Controls.Add(this.uwasaButton);
			this.Controls.Add(this.groupBox1);
			this.Icon = ((System.Drawing.Icon)(resources.GetObject("$this.Icon")));
			this.MaximizeBox = false;
			this.MaximumSize = new System.Drawing.Size(556, 756);
			this.MinimizeBox = false;
			this.MinimumSize = new System.Drawing.Size(456, 199);
			this.Name = "BookmarkForm";
			this.StartPosition = System.Windows.Forms.FormStartPosition.CenterScreen;
			this.Text = "ubN}[N";
			this.Closing += new System.ComponentModel.CancelEventHandler(this.BookmarkForm_Closing);
			this.groupBox1.ResumeLayout(false);
			this.ResumeLayout(false);

		}
		#endregion

		// 2006/07/11 Y.T ADD
		public void addBookMarkAuto(string sname ,string surl)
		{
			addBookMark = true;
			// Copy the entered data into a new Bookmark object
			this.bookmark_i = new Bookmark();
			this.bookmark_i.Name = sname;
			this.bookmark_i.Url = surl;

			if(this.noOfHeadlinesTextBox_i.Text != "")
			{
				this.bookmark_i.NoOfHeadlines = Convert.ToInt32(this.noOfHeadlinesTextBox_i.Text);
			}
			this.bookmark_i.Display = this.displayCheckBox_i.Checked;
				
			// Add the bookmark to the list of bookmarks
			this.controller_i.Bookmarks.AddBookmark(this.bookmark_i);
			this.Close();

		}

		private void digestButton_Click(object sender, System.EventArgs e)
		{
			addBookMarkAuto("،_CWFXg" ,"http://www.syokenshimpo.co.jp/rss/digest.rdf");
		}

		private void uwasaButton_Click(object sender, System.EventArgs e)
		{
			addBookMarkAuto("̉\" ,"http://www.syokenshimpo.co.jp/rss/uwasa.rdf");
		}

		private void jitsurokuButton_Click(object sender, System.EventArgs e)
		{
			addBookMarkAuto("^" ,"http://www.syokenshimpo.co.jp/rss/jitsuroku.rdf");
		}

		private void IPOButton_Click(object sender, System.EventArgs e)
		{
			addBookMarkAuto("IPO" ,"http://www.syokenshimpo.co.jp/rss/ipo.rdf");
		}

		private void foreignButton_Click(object sender, System.EventArgs e)
		{
			addBookMarkAuto("On" ,"http://www.syokenshimpo.co.jp/rss/foreign.rdf");
		}

		private void summary_kaigaiButton_Click(object sender, System.EventArgs e)
		{
			addBookMarkAuto("COsT" ,"http://www.syokenshimpo.co.jp/rss/summary_kaigai.rdf");
		}

		private void summary_kokunaiButton_Click(object sender, System.EventArgs e)
		{
			addBookMarkAuto("sT" ,"http://www.syokenshimpo.co.jp/rss/summary_kokunai.rdf");
		}

		private void keizaiButton_Click(object sender, System.EventArgs e)
		{
			addBookMarkAuto("oώwWEv" ,"http://www.syokenshimpo.co.jp/rss/keizai.rdf");
		}

		private void ratingButton_Click(object sender, System.EventArgs e)
		{
			addBookMarkAuto("it" ,"http://www.syokenshimpo.co.jp/rss/rating.rdf");
		}

		private void kabuka_rankingButton_Click(object sender, System.EventArgs e)
		{
			addBookMarkAuto("LO" ,"http://www.syokenshimpo.co.jp/rss/kabuka_ranking.rdf");
		}

		private void kessan_scheduleButton_Click(object sender, System.EventArgs e)
		{
			addBookMarkAuto("Z\\" ,"http://www.syokenshimpo.co.jp/rss/kessan-schedule.rdf");
		}

		private void kessan_explanatoryButton_Click(object sender, System.EventArgs e)
		{
			addBookMarkAuto("Z\" ,"http://www.syokenshimpo.co.jp/rss/kessan-explanatory.rdf");
		}

		private void gyosekiButton_Click(object sender, System.EventArgs e)
		{
			addBookMarkAuto("ƋƐуj[X" ,"http://www.syokenshimpo.co.jp/rss/gyoseki.rdf");
		}

		private void bunkatsuButton_Click(object sender, System.EventArgs e)
		{
			addBookMarkAuto("EzE" ,"http://www.syokenshimpo.co.jp/rss/bunkatsu.rdf");
		}

		private void hotnewsButton_Click(object sender, System.EventArgs e)
		{
			addBookMarkAuto("Vzbgj[X" ,"http://www.syokenshimpo.co.jp/rss/hotnews.rdf");
		}

		private void chumokuButton_Click(object sender, System.EventArgs e)
		{
			addBookMarkAuto("ڊ̓" ,"http://www.syokenshimpo.co.jp/rss/chumoku.rdf");
		}

		private void exchangeButton_Click(object sender, System.EventArgs e)
		{
			addBookMarkAuto("ב(JPY)" ,"http://worris.sakura.ne.jp/worris/rate/raterss.cgi?USD=on&EUR=on&GBP=on&AUD=on&CAD=on&CHF=on&NZD=on&lang=en");
		}

		private void stockButton_Click(object sender, System.EventArgs e)
		{
			addBookMarkAuto("o" ,"http://worris.sakura.ne.jp/worris/stock/stockrss.cgi?code=&market=t&NIKKEI=on&TOPIX=on&JASDAQ=on");
		}

		private void exchangeButton2_Click(object sender, System.EventArgs e)
		{
			addBookMarkAuto("ב(USD)" ,"http://currencysource.com/RSS/USD.xml");
		}
		// 2006/07/11 Y.T END
	}
}
