/* -------------------------------------------------------------------------
 | Copyright (C) 2006  Ali Rawashdeh
 | This program is free software; you can redistribute it and/or modify
 | it under the terms of the GNU General Public License as published by
 | the Free Software Foundation; either version 2 of the License, or
 | (at your option) any later version.
 | 
 | This program is distributed in the hope that it will be useful,
 | but WITHOUT ANY WARRANTY; without even the implied warranty of
 | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 | GNU General Public License for more details.
 | 
 | You should have received a copy of the GNU General Public License along
 | with this program (see License.txt); if not, write to the Free Software
 | Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 --------------------------------------------------------------------------*/
using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using HomeDev.RSSTicker.Objects;
using HomeDev.RSSTicker.Controller;

namespace HomeDev.RSSTicker.UI
{
	public delegate void EnableBookmarksFormDelegate();

	/// <summary>
	/// Summary description for BookmarksForm.
	/// </summary>
	public class BookmarksForm : System.Windows.Forms.Form
	{
		// Declarations
		private System.Windows.Forms.Button addBookmarkButton_i;
		private System.Windows.Forms.Button removeBookmarkButton_i;
		private System.Windows.Forms.GroupBox groupBox1;
		private System.Windows.Forms.Button cancelButton_i;
		private System.Windows.Forms.Button okButton_i;
		private System.Windows.Forms.Button editButton_i;
		private System.Windows.Forms.CheckedListBox bookmarksListBox_i;
		private System.ComponentModel.Container components = null;

		private HomeDev.RSSTicker.Controller.Controller controller_i;
		private Bookmarks oldBookmarks_i;
		private bool save_i;
		private System.Windows.Forms.Button btnMoveUp_i;
		private System.Windows.Forms.Button btnMoveDown_i;
		private EnableBookmarksFormDelegate enableBookmarksFormDelegate_i;

		// 07/13 Y.T ADD For initial setting
		//static private bool firsttime_i;
		private Bookmark  iniBookmark_i;
		const string iniName_i      = "،_CWFXg";
		const string iniurl_i       = "http://www.syokenshimpo.co.jp/rss/digest.rdf";
		const int    iniheadlines_i = 5;
		// 07/13 Y.T END For initial setting

		#region ctor

		public BookmarksForm(HomeDev.RSSTicker.Controller.Controller controller_p)
		{
			// Required for Windows Form Designer support
			InitializeComponent();

			// Set up the delegate to enable the form
			enableBookmarksFormDelegate_i = new EnableBookmarksFormDelegate(this.EnableForm);

			// Set up the Event Handlers
			this.addBookmarkButton_i.Click += new EventHandler(this.addBookmarkButton_MouseDown);
			this.removeBookmarkButton_i.Click += new EventHandler(this.removeBookmarkButton_MouseDown);
			this.editButton_i.Click += new EventHandler(this.editButton_MouseDown);
			this.cancelButton_i.Click += new EventHandler(this.cancelButton_MouseDown);
			this.okButton_i.Click += new EventHandler(this.okButton_MouseDown);
			this.Load += new EventHandler(this.this_LoadMethod);
			this.Closing += new CancelEventHandler(this.this_Closing);
			this.bookmarksListBox_i.ItemCheck += new ItemCheckEventHandler(this.bookmarksListBox_ItemCheck);
			this.bookmarksListBox_i.SelectedIndexChanged += new EventHandler(bookmarksListBox_i_SelectedIndexChanged);
			
			// Initialise the bookmarks list box
			controller_i = controller_p;
			
			// Make copy of the Bookmarks object
			this.oldBookmarks_i = new Bookmarks();

			foreach(Bookmark bookmark in this.controller_i.Bookmarks.Items)
			{
				oldBookmarks_i.AddBookmark(bookmark.Duplicate());
			}

			// 07/13 Y.T ADD For Initial Setting 
			if(MainBar.firsttime_i)
			{
				this.iniBookmark_i = new Bookmark(iniName_i ,iniurl_i,iniheadlines_i);

				BookmarkForm bookmarkform = new BookmarkForm(controller_i,this.iniBookmark_i,enableBookmarksFormDelegate_i);
				bookmarkform.addBookMarkAuto(iniName_i ,iniurl_i);
				MainBar.firsttime_i = false;
			}
			// 07/13 Y.T END For Initial Setting 

			// The listbox is displayed anyway as Activated event was called
			this.save_i = false;
		}

		#endregion ctor

		#region Event Handler Methods

		public void addBookmarkButton_MouseDown(object source, EventArgs args)
		{
			BookmarkForm bf = new BookmarkForm(this.controller_i,null, this.enableBookmarksFormDelegate_i);
			bf.Show();
			this.Enabled = false;
		}

		public void removeBookmarkButton_MouseDown(object source, EventArgs args)
		{
			// Only remove a bookmark if a selection is made
			if(this.bookmarksListBox_i.SelectedIndex != -1)
			{
				// Make a new bookmarks object
				Bookmarks newBookmarks = new Bookmarks();
				// Go through each bookmarks object and only keep it if it isnt selected
				foreach(Bookmark bookmark in this.controller_i.Bookmarks.Items)
				{
					if(bookmark != this.controller_i.Bookmarks.Items[this.bookmarksListBox_i.SelectedIndex])
					{
						newBookmarks.AddBookmark(bookmark);
					}
				}
				// Refresh the display
				this.controller_i.Bookmarks = newBookmarks;
				this.DisplayBookmarks();
			}
		}

		/// <summary>
		/// This method is called when the Edit button is pressed
		/// </summary>
		public void editButton_MouseDown(object source, EventArgs args)
		{
			// Only open if a bookmark is selected
			if(bookmarksListBox_i.SelectedItem != null)
			{
				BookmarkForm bf = new BookmarkForm(this.controller_i, this.controller_i.Bookmarks.Items[bookmarksListBox_i.SelectedIndex], this.enableBookmarksFormDelegate_i);
				bf.Show();
				this.Enabled = false;
			}
		}

		/// <summary>
		/// This method is called when the Cancel button is pressed
		/// </summary>
		public void cancelButton_MouseDown(object source, EventArgs args)
		{
			this.controller_i.Bookmarks = this.oldBookmarks_i;
			this.Close();
		}

		/// <summary>
		/// This method is called when the Save button is pressed
		/// </summary>
		public void okButton_MouseDown(object source, EventArgs args)
		{
			this.save_i = true;
			this.Close();
			this.controller_i.Bookmarks.Save("Bookmarks.xml");
			this.controller_i.ForceFeedsUpdate();
		}

		/// <summary>
		/// This method is called when the form gains focus
		/// </summary>
		public void this_LoadMethod(object source, EventArgs args)
		{
			this.DisplayBookmarks();
		}

		/// <summary>
		/// This method is called when the form is closed
		/// </summary>
		public void this_Closing(object source, CancelEventArgs args)
		{
			if(!this.save_i)
			{
				this.controller_i.Bookmarks = this.oldBookmarks_i;
			}
		}

		/// <summary>
		/// This method is called when an item is checked or unchecked in the bookmark list
		/// </summary>
		public void bookmarksListBox_ItemCheck(object source, ItemCheckEventArgs args)
		{
			if(this.bookmarksListBox_i.SelectedIndex != -1)
			{
				int index = this.bookmarksListBox_i.SelectedIndex;
				this.controller_i.Bookmarks.Items[index].Display = !this.controller_i.Bookmarks.Items[index].Display;	
			}

		}	

		/// <summary>
		/// This method is called when an selected item in the bookmarks list changes
		/// </summary>
		/// <param name="sender"></param>
		/// <param name="e"></param>
		private void bookmarksListBox_i_SelectedIndexChanged(object sender, EventArgs e)
		{
			if(this.bookmarksListBox_i.SelectedItems.Count > 0)
			{
				this.removeBookmarkButton_i.Enabled = true;
				this.editButton_i.Enabled = true;
				this.btnMoveDown_i.Enabled = true;
				this.btnMoveUp_i.Enabled = true;
			}
			else
			{
				this.removeBookmarkButton_i.Enabled = false;
				this.editButton_i.Enabled = false;
				this.btnMoveDown_i.Enabled = false;
				this.btnMoveUp_i.Enabled = false;
			}
		}

		/// <summary>
		/// This method is called when the Move Up button is clicked
		/// </summary>
		/// <param name="sender"></param>
		/// <param name="e"></param>
		private void btnMoveUp_i_Click(object sender, System.EventArgs e)
		{
			int index = this.bookmarksListBox_i.SelectedIndex;
			this.controller_i.Bookmarks.MoveUp(this.controller_i.Bookmarks.Items[index]);
			this.DisplayBookmarks();
			if(index > 0)
			{
				this.bookmarksListBox_i.SelectedIndex = index - 1;
			}
			else
			{
				this.bookmarksListBox_i.SelectedIndex = index;
			}
		}

		/// <summary>
		/// This method is called when the Move Down button is clicked
		/// </summary>
		/// <param name="sender"></param>
		/// <param name="e"></param>
		private void btnMoveDown_i_Click(object sender, System.EventArgs e)
		{
			int index = this.bookmarksListBox_i.SelectedIndex;
			this.controller_i.Bookmarks.MoveDown(this.controller_i.Bookmarks.Items[index]);
			this.DisplayBookmarks();
			if(index < this.bookmarksListBox_i.Items.Count - 1)
			{
				this.bookmarksListBox_i.SelectedIndex = index + 1;
			}
			else
			{
				this.bookmarksListBox_i.SelectedIndex = index;
			}
		}


		#endregion Event Handler Methods

		#region Public Methods

		/// <summary>
		/// This method enables the bookmarks form
		/// </summary>
		public void EnableForm()
		{
			this.Enabled = true;
			this.BringToFront();
			this.DisplayBookmarks();
		}

		/// <summary>
		/// This method displays the bookmarks in the listbox
		/// </summary>
		/// <param name="bookmarks_p"></param>
		public void DisplayBookmarks()
		{
			// Clear the bookmarks listbox
			this.bookmarksListBox_i.Items.Clear();

			// Add each bookmark to the list
			foreach(Bookmark bookmark in this.controller_i.Bookmarks.Items)
			{
				this.bookmarksListBox_i.Items.Add(bookmark.Name, bookmark.Display);
			}
		}

		#endregion Public Methods

		#region Other Methods

		/// <summary>
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#endregion Other Methods

		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			System.Resources.ResourceManager resources = new System.Resources.ResourceManager(typeof(BookmarksForm));
			this.addBookmarkButton_i = new System.Windows.Forms.Button();
			this.removeBookmarkButton_i = new System.Windows.Forms.Button();
			this.groupBox1 = new System.Windows.Forms.GroupBox();
			this.btnMoveDown_i = new System.Windows.Forms.Button();
			this.btnMoveUp_i = new System.Windows.Forms.Button();
			this.editButton_i = new System.Windows.Forms.Button();
			this.bookmarksListBox_i = new System.Windows.Forms.CheckedListBox();
			this.cancelButton_i = new System.Windows.Forms.Button();
			this.okButton_i = new System.Windows.Forms.Button();
			this.groupBox1.SuspendLayout();
			this.SuspendLayout();
			// 
			// addBookmarkButton_i
			// 
			this.addBookmarkButton_i.Location = new System.Drawing.Point(216, 22);
			this.addBookmarkButton_i.Name = "addBookmarkButton_i";
			this.addBookmarkButton_i.Size = new System.Drawing.Size(72, 22);
			this.addBookmarkButton_i.TabIndex = 1;
			this.addBookmarkButton_i.Text = "VK";
			// 
			// removeBookmarkButton_i
			// 
			this.removeBookmarkButton_i.Enabled = false;
			this.removeBookmarkButton_i.Location = new System.Drawing.Point(216, 81);
			this.removeBookmarkButton_i.Name = "removeBookmarkButton_i";
			this.removeBookmarkButton_i.Size = new System.Drawing.Size(72, 22);
			this.removeBookmarkButton_i.TabIndex = 2;
			this.removeBookmarkButton_i.Text = "";
			// 
			// groupBox1
			// 
			this.groupBox1.Controls.Add(this.btnMoveDown_i);
			this.groupBox1.Controls.Add(this.btnMoveUp_i);
			this.groupBox1.Controls.Add(this.editButton_i);
			this.groupBox1.Controls.Add(this.removeBookmarkButton_i);
			this.groupBox1.Controls.Add(this.addBookmarkButton_i);
			this.groupBox1.Controls.Add(this.bookmarksListBox_i);
			this.groupBox1.Location = new System.Drawing.Point(8, 7);
			this.groupBox1.Name = "groupBox1";
			this.groupBox1.Size = new System.Drawing.Size(304, 192);
			this.groupBox1.TabIndex = 5;
			this.groupBox1.TabStop = false;
			this.groupBox1.Text = "ubN}[N";
			// 
			// btnMoveDown_i
			// 
			this.btnMoveDown_i.Enabled = false;
			this.btnMoveDown_i.Location = new System.Drawing.Point(216, 140);
			this.btnMoveDown_i.Name = "btnMoveDown_i";
			this.btnMoveDown_i.Size = new System.Drawing.Size(72, 22);
			this.btnMoveDown_i.TabIndex = 10;
			this.btnMoveDown_i.Text = "Ɉړ";
			this.btnMoveDown_i.Click += new System.EventHandler(this.btnMoveDown_i_Click);
			// 
			// btnMoveUp_i
			// 
			this.btnMoveUp_i.Enabled = false;
			this.btnMoveUp_i.Location = new System.Drawing.Point(216, 111);
			this.btnMoveUp_i.Name = "btnMoveUp_i";
			this.btnMoveUp_i.Size = new System.Drawing.Size(72, 22);
			this.btnMoveUp_i.TabIndex = 9;
			this.btnMoveUp_i.Text = "Ɉړ";
			this.btnMoveUp_i.Click += new System.EventHandler(this.btnMoveUp_i_Click);
			// 
			// editButton_i
			// 
			this.editButton_i.Enabled = false;
			this.editButton_i.Location = new System.Drawing.Point(216, 52);
			this.editButton_i.Name = "editButton_i";
			this.editButton_i.Size = new System.Drawing.Size(72, 22);
			this.editButton_i.TabIndex = 5;
			this.editButton_i.Text = "ҏW";
			// 
			// bookmarksListBox_i
			// 
			this.bookmarksListBox_i.Location = new System.Drawing.Point(16, 22);
			this.bookmarksListBox_i.Name = "bookmarksListBox_i";
			this.bookmarksListBox_i.Size = new System.Drawing.Size(184, 144);
			this.bookmarksListBox_i.TabIndex = 8;
			// 
			// cancelButton_i
			// 
			this.cancelButton_i.Location = new System.Drawing.Point(248, 207);
			this.cancelButton_i.Name = "cancelButton_i";
			this.cancelButton_i.Size = new System.Drawing.Size(64, 21);
			this.cancelButton_i.TabIndex = 6;
			this.cancelButton_i.Text = "LZ";
			// 
			// okButton_i
			// 
			this.okButton_i.Location = new System.Drawing.Point(176, 207);
			this.okButton_i.Name = "okButton_i";
			this.okButton_i.Size = new System.Drawing.Size(64, 21);
			this.okButton_i.TabIndex = 7;
			this.okButton_i.Text = "OK";
			// 
			// BookmarksForm
			// 
			this.AutoScaleBaseSize = new System.Drawing.Size(5, 12);
			this.ClientSize = new System.Drawing.Size(320, 253);
			this.Controls.Add(this.okButton_i);
			this.Controls.Add(this.cancelButton_i);
			this.Controls.Add(this.groupBox1);
			this.Icon = ((System.Drawing.Icon)(resources.GetObject("$this.Icon")));
			this.MaximizeBox = false;
			this.MaximumSize = new System.Drawing.Size(328, 287);
			this.MinimumSize = new System.Drawing.Size(328, 287);
			this.Name = "BookmarksForm";
			this.StartPosition = System.Windows.Forms.FormStartPosition.CenterScreen;
			this.Text = "ubN}[NҏW";
			this.groupBox1.ResumeLayout(false);
			this.ResumeLayout(false);

		}
		#endregion		

	}
}
