/* -------------------------------------------------------------------------
 | Copyright (C) 2006  Ali Rawashdeh
 | This program is free software; you can redistribute it and/or modify
 | it under the terms of the GNU General Public License as published by
 | the Free Software Foundation; either version 2 of the License, or
 | (at your option) any later version.
 | 
 | This program is distributed in the hope that it will be useful,
 | but WITHOUT ANY WARRANTY; without even the implied warranty of
 | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 | GNU General Public License for more details.
 | 
 | You should have received a copy of the GNU General Public License along
 | with this program (see License.txt); if not, write to the Free Software
 | Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 --------------------------------------------------------------------------*/
using System;
using System.Diagnostics;
using System.IO;
using System.Reflection;

namespace HomeDev.Useful
{
	/// <summary>
	/// This class is used to create a log file and output to it
	/// </summary>
	public class Logger
	{
		private static TextWriterTraceListener traceListener_i;
		private static FileStream file_i;
		private static bool isOn_i;

		public Logger()
		{
		}

		/// <summary>
		/// This method opens up the log file, or creates one appropriately
		/// </summary>
		/// <param name="file_p"></param>
		/// <param name="level"></param>
		public static void Open(string file_p,bool isOn_p)
		{
			try
			{
				file_i = File.Open(file_p,System.IO.FileMode.Append);
				traceListener_i = new TextWriterTraceListener(file_i);
				Trace.Listeners.Add(traceListener_i);	
			}
			catch
			{
				throw new Exception("Error creating/accessing log file");
			}
			Trace.AutoFlush = true;
			isOn_i = isOn_p;
		}

		/// <summary>
		/// This method closes the log file
		/// </summary>
		public static void Close()
		{
			Trace.Listeners.Remove(traceListener_i);
			traceListener_i.Dispose();
			file_i.Close();
		}

		/// <summary>
		/// This method outputs a message to the log file
		/// </summary>
		/// <param name="message_p"></param>
		public static void Log(string message_p)
		{
			if(isOn_i)
			{
				Trace.WriteLine(System.DateTime.Now.ToString() + 
					" [" + WhoCalledMe() + "] " + message_p);
			}
		}

		/// <summary>
		/// This method sets whether the log is turned on or off
		/// </summary>
		/// <param name="value_p"></param>
		public static void SetLogOnOrOff(bool value_p)
		{
			isOn_i = value_p;
		}	

		/// <summary>
		/// This method finds out who made a call to the Log method
		/// </summary>
		/// <returns></returns>
		private static string WhoCalledMe()
		{
			StackTrace stackTrace = new StackTrace();
			StackFrame stackFrame = stackTrace.GetFrame(2);
			MethodBase methodBase = stackFrame.GetMethod();
			return methodBase.ReflectedType	+ "." + methodBase.Name;
		}

	}
}
